/*
=========================================================================
	TESTSL.CPP
		Test suite for the StrList.cpp string list class.
	Copyright (c) 2003-2004 by Daniel R. Collins. All rights reserved.
  You may freely copy this document, if copyright notice is maintained.
=========================================================================
*/

// Program identification
#define APP_NAME          "TestSL"
#define AUTHOR_NAME       "Daniel R. Collins"
#define COPYRIGHT_YEAR    "2003"
#define VERSION_NUMBER    "1.01"


// Includes
#include <assert.h>
#include <string.h>
#include <stdio.h>
#include "strlist.h"
#include "meminst.h"


/*
=================================================
	Main function
=================================================
*/

int main (void)
	{
	// Print banner
	printf("\n" APP_NAME " beginning.\n");

	/*
	-----------------------------------------------
	Test StringNode
	-----------------------------------------------
	*/

	char s0[] = "This is a test string.";
	StringNode *node = new StringNode(s0);

	// Test getString
	assert(!strcmp(node->getString(), s0));

	// Test getNext
	assert(node->getNext() == NULL);

	// Cleanup row
	delete node;
  assert(memInstGetBlocks() == 0);
  assert(memInstGetBytes() == 0);


	/*
	-----------------------------------------------
	Test StringList
	-----------------------------------------------
	*/

	StringList *list = new StringList();
	char s1[] = "Here is the first string.";
	char s2[] = "Here is the second string.";
	char s3[] = "Here is the third string.";

	// Test appendString
	list->appendString(s1);
	list->appendString(s2);
	list->appendString(s3);

	// Test getNumStrings
	assert(list->getNumStrings() == 3);

	// Test getString
	assert(!strcmp(list->getString(0), s1));
	assert(!strcmp(list->getString(1), s2));
	assert(!strcmp(list->getString(2), s3));
	assert(list->getString(3) == NULL);

	// Cleanup table
  delete list;
  assert(memInstGetBlocks() == 0);
  assert(memInstGetBytes() == 0);

	// Report & return success
  printf(APP_NAME " finished successfully.\n");
	return 0;
	}

